import { readable, writable } from 'svelte/store';


function createMemberStore() {
    const { subscribe, set, update } = writable(null)

    return {
        subscribe: subscribe,
        set: set,
        addIntro: (intro: IntroIndex) => { update((n) => n.intros.push(intro)); return intro },
        pullData: async (token) => {
            const response = (await (await fetch(
                'http://localhost:7756/me',
                { headers: {"token": token} })).json())

            if (response === "NoUserFound") {
                return;
            } else {
                set({ token: token, ...response.Me }) 
            }
        }
    }
}

function createIntroStore() {
    const { subscribe, set, update } = writable(new Map())

    return {
        subscribe: subscribe,
        fetchIntros: async (guilds) => {
            console.debug('Fetching intros');
            console.log(guilds)

            let intros = new Map();

            for (const guild of guilds) {
                const response = (await (await fetch(`http://localhost:7756/intros/${guild.name}`)).json())
                    if (response !== "NoGuildFound") {
                    let guild_intros = new Map();

                    Object.entries(response.Intros).forEach(([index, intro]) => {
                        if (!!intro.File) {
                            guild_intros.set(index, { name: intro.File.friendlyName, filename: intro.File.filename });
                        } else if (!!intro.Online) {
                            guild_intros.set(index, { name: intro.Online.friendlyName, filename: intro.Online.filename });
                        }
                    })

                    intros.set(guild.name, guild_intros);
                }
            }

            console.debug('Setting Intros store');
            console.debug(intros);
            set(intros)
        }
    }


}

export const intros = createIntroStore()
export const member = createMemberStore()

